@@ -22,4 +22,16 @@ class BeamlineElement(SynedObject):
         return self._optical_element
 
     def get_coordinates(self):
-        return self._coordinates
\ No newline at end of file
+        return self._coordinates
+
+    def set_optical_element(self, value):
+        if isinstance(value, OpticalElement):
+            self._optical_element = value
+        else:
+            raise Exception("entry is not an instance of OpticalElement")
+
+    def set_coordinates(self, value):
+        if isinstance(value, ElementCoordinates):
+            self._coordinates = value
+        else:
+            raise Exception("entry is not an instance of ElementCoordinates")
